=== modified file 'Makefile'
--- Makefile	2011-09-20 22:33:07 +0000
+++ Makefile	2011-09-27 07:58:30 +0000
@@ -253,7 +253,7 @@
 	$(PY) cronscripts/merge-proposal-jobs.py -v
 
 run: build inplace stop
-	bin/run -r librarian,google-webservice,memcached,rabbitmq -i $(LPCONFIG)
+	bin/run -r librarian,google-webservice,memcached,rabbitmq,txlongpoll -i $(LPCONFIG)
 
 run-testapp: LPCONFIG=testrunner-appserver
 run-testapp: build inplace stop
@@ -270,7 +270,7 @@
 
 run_all: build inplace stop
 	bin/run \
-	 -r librarian,sftp,forker,mailman,codebrowse,google-webservice,memcached,rabbitmq \
+	 -r librarian,sftp,forker,mailman,codebrowse,google-webservice,memcached,rabbitmq,txlongpoll \
 	 -i $(LPCONFIG)
 
 run_codebrowse: build

=== modified file 'configs/development/launchpad-lazr.conf'
--- configs/development/launchpad-lazr.conf	2011-09-24 03:03:08 +0000
+++ configs/development/launchpad-lazr.conf	2011-09-27 07:58:30 +0000
@@ -246,6 +246,11 @@
 password: guest
 virtual_host: /
 
+[txlongpoll]
+launch: True
+frontend_port: 22435
+uri: /+longpoll/
+
 [reclaimbranchspace]
 error_dir: /var/tmp/codehosting.test
 oops_prefix: RBS

=== modified file 'configs/development/local-launchpad-apache'
--- configs/development/local-launchpad-apache	2011-04-05 23:36:31 +0000
+++ configs/development/local-launchpad-apache	2011-09-27 07:58:30 +0000
@@ -12,6 +12,7 @@
   ProxyPreserveHost on
 
   ProxyPass / http://localhost:8087/ retry=1
+  ProxyPass /+longpoll/ http://localhost:22435/ retry=1
 </VirtualHost>
 
 <VirtualHost 127.0.0.88:80>

=== modified file 'configs/testrunner/launchpad-lazr.conf'
--- configs/testrunner/launchpad-lazr.conf	2011-09-15 14:04:10 +0000
+++ configs/testrunner/launchpad-lazr.conf	2011-09-27 07:58:30 +0000
@@ -208,6 +208,11 @@
 password: none
 virtual_host: none
 
+[txlongpoll]
+launch: False
+frontend_port: none
+uri: none
+
 [request_daily_builds]
 oops_prefix: TRDB
 error_dir: /var/tmp/lperr.test

=== modified file 'lib/canonical/config/schema-lazr.conf'
--- lib/canonical/config/schema-lazr.conf	2011-09-24 02:40:51 +0000
+++ lib/canonical/config/schema-lazr.conf	2011-09-27 07:58:30 +0000
@@ -1721,6 +1721,16 @@
 # datatype: string
 virtual_host: none
 
+[txlongpoll]
+# Should TxLongPoll be launched by default?
+# datatype: boolean
+launch: False
+# The port at which TxLongPoll is listening.
+# datatype: string
+frontend_port: none
+# The uri that should be a proxy to the TxLongPoll server.
+uri: none
+
 [reclaimbranchspace]
 # The database user which will be used by this process.
 # datatype: string

=== modified file 'lib/canonical/launchpad/scripts/runlaunchpad.py'
--- lib/canonical/launchpad/scripts/runlaunchpad.py	2011-09-21 00:15:46 +0000
+++ lib/canonical/launchpad/scripts/runlaunchpad.py	2011-09-27 07:58:30 +0000
@@ -27,6 +27,7 @@
 from lp.services.googlesearch import googletestservice
 from lp.services.mailman import runmailman
 from lp.services.osutils import ensure_directory_exists
+from lp.services.txlongpoll.server import TxLongPollServer
 from lp.services.rabbit.server import RabbitServer
 
 
@@ -238,6 +239,26 @@
         self.useFixture(self.server)
 
 
+class TxLongPollService(Service):
+    """A TxLongPoll service."""
+
+    @property
+    def should_launch(self):
+        return config.txlongpoll.launch
+
+    def launch(self):
+        broker_hostname, broker_port = as_host_port(
+            config.rabbitmq.host, None, None)
+        self.server = TxLongPollServer(
+            frontend_port = config.txlongpoll.frontend_port,
+            broker_user = config.rabbitmq.userid,
+            broker_password = config.rabbitmq.password,
+            broker_vhost = config.rabbitmq.virtual_host,
+            broker_host = broker_hostname,
+            broker_port = broker_port)
+        self.useFixture(self.server)
+
+
 def stop_process(process):
     """kill process and BLOCK until process dies.
 
@@ -263,6 +284,7 @@
     'google-webservice': GoogleWebService(),
     'memcached': MemcachedService(),
     'rabbitmq': RabbitService(),
+    'txlongpoll': TxLongPollService(),
     }
 
 

=== modified file 'lib/canonical/launchpad/scripts/tests/test_runlaunchpad.py'
--- lib/canonical/launchpad/scripts/tests/test_runlaunchpad.py	2011-07-06 08:43:16 +0000
+++ lib/canonical/launchpad/scripts/tests/test_runlaunchpad.py	2011-09-27 07:58:30 +0000
@@ -156,6 +156,10 @@
         if config.rabbitmq.launch:
             expected.append(SERVICES['rabbitmq'])
 
+        # TxLongPoll may or may not be asked to run.
+        if config.txlongpoll.launch:
+            expected.append(SERVICES['txlongpoll'])
+
         expected = sorted(expected)
         self.assertEqual(expected, services)
 

=== modified file 'lib/lp/services/rabbit/tests/test_server.py'
--- lib/lp/services/rabbit/tests/test_server.py	2011-09-14 16:57:11 +0000
+++ lib/lp/services/rabbit/tests/test_server.py	2011-09-27 07:58:30 +0000
@@ -1,7 +1,7 @@
 # Copyright 2011 Canonical Ltd.  This software is licensed under the
 # GNU Affero General Public License version 3 (see the file LICENSE).
 
-"""Tests for lp.testing.fixture."""
+"""Tests for lp.services.rabbit.RabbitServer."""
 
 __metaclass__ = type
 

=== added directory 'lib/lp/services/txlongpoll'
=== added file 'lib/lp/services/txlongpoll/__init__.py'
=== added file 'lib/lp/services/txlongpoll/server.py'
--- lib/lp/services/txlongpoll/server.py	1970-01-01 00:00:00 +0000
+++ lib/lp/services/txlongpoll/server.py	2011-09-27 07:58:30 +0000
@@ -0,0 +1,39 @@
+# Copyright 2011 Canonical Ltd.  This software is licensed under the
+# GNU Affero General Public License version 3 (see the file LICENSE).
+
+"""TxLongPoll server fixture."""
+
+__metaclass__ = type
+__all__ = [
+    'TxLongPollServer',
+    ]
+
+from textwrap import dedent
+
+from txlongpollfixture.server import TxLongPollFixture
+from rabbitfixture.server import RabbitServer
+
+
+class TxLongPollServer(TxLongPollFixture):
+    """A TxLongPoll server fixture with Launchpad-specific config.
+
+    :ivar service_config: A snippet of .ini that describes the `txlongpoll`
+        configuration.
+    """
+
+    def setUp(self):
+        super(TxLongPollServer, self).setUp()
+        self.rabbitserver = RabbitServer()
+        self.useFixture(self.rabbitserver)
+        self.config['service_config'] = dedent("""\
+            [rabbitmq]
+            host: localhost:%d
+            userid: guest
+            password: guest
+            virtual_host: /
+
+            [txlongpoll]
+            frontend_port: %d
+            """ % (
+                self.rabbitserver.config.port,
+                self.config['frontend_port']))

=== added directory 'lib/lp/services/txlongpoll/tests'
=== added file 'lib/lp/services/txlongpoll/tests/__init__.py'
=== added file 'lib/lp/services/txlongpoll/tests/test_server.py'
--- lib/lp/services/txlongpoll/tests/test_server.py	1970-01-01 00:00:00 +0000
+++ lib/lp/services/txlongpoll/tests/test_server.py	2011-09-27 07:58:30 +0000
@@ -0,0 +1,45 @@
+# Copyright 2011 Canonical Ltd.  This software is licensed under the
+# GNU Affero General Public License version 3 (see the file LICENSE).
+
+"""Tests for lp.services.rabbit.TxLongPollServer."""
+
+__metaclass__ = type
+
+from ConfigParser import SafeConfigParser
+from StringIO import StringIO
+
+from canonical.testing.layers import BaseLayer
+from lp.services.txlongpoll.server import TxLongPollServer
+from lp.testing import TestCase
+
+
+class TestTxLongPollServer(TestCase):
+
+    layer = BaseLayer
+
+    def test_service_config(self):
+        # TxLongPollServer pokes some .ini configuration into its config.
+        fixture = self.useFixture(TxLongPollServer(
+            broker_user='guest', broker_password='guest', broker_vhost='/',
+            broker_port=123, frontend_port=None))
+        service_config = SafeConfigParser()
+        service_config.readfp(StringIO(fixture.config['service_config']))
+        self.assertEqual(
+            ["rabbitmq", "txlongpoll"], sorted(service_config.sections()))
+        # txlongpoll section
+        expected = {
+            "frontend_port": "%d" % fixture.config['frontend_port'],
+            }
+        observed = dict(service_config.items("txlongpoll"))
+        self.assertEqual(expected, observed)
+        # rabbitmq section
+        expected = {
+            "host": "localhost:%d" % (
+                fixture.rabbitserver.config.port),
+            "password": "guest",
+            "userid": "guest",
+            "virtual_host": "/",
+            }
+        observed = dict(service_config.items("rabbitmq"))
+        self.assertEqual(expected, observed)
+

=== modified file 'setup.py'
--- setup.py	2011-09-26 08:35:37 +0000
+++ setup.py	2011-09-27 07:58:30 +0000
@@ -80,6 +80,7 @@
         'storm',
         'testtools',
         'timeline',
+        'txlongpollfixture',
         'transaction',
         'Twisted',
         'wadllib',

=== modified file 'versions.cfg'
--- versions.cfg	2011-09-26 08:35:37 +0000
+++ versions.cfg	2011-09-27 07:58:30 +0000
@@ -93,6 +93,7 @@
 transaction = 1.0.0
 txamqp = 0.4
 txlongpoll = 0.2.2
+txlongpollfixture = 0.1
 Twisted = 11.0.0
 unittest2 = 0.5.1
 uuid = 1.30

